@@ -5,7 +5,7 @@ package Test::Sah::Schema;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Test-Sah-Schema'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -98,24 +98,26 @@ sub sah_schema_module_ok {
                                 my ($errmsg, $res)  = @{ $vdr->($value) };
                             if ($eg->{valid}) {
                                 if ($errmsg) {
-                                    $Test->ok(0, "Data should be valid, but isn't");
+                                    $Test->ok(0, "Value should be valid, but isn't");
                                     $ok = 0;
                                     return;
                                 } else {
-                                    $Test->ok(1, "Data should be valid");
+                                    $Test->ok(1, "Value should be valid");
                                 }
                             } else {
                                 if (!$errmsg) {
-                                    $Test->ok(0, "Data shouldn't be valid, but is");
+                                    $Test->ok(0, "Value shouldn't be valid, but is");
                                     $ok = 0;
                                     return;
                                 } else {
-                                    $Test->ok(1, "Data should not be valid");
+                                    $Test->ok(1, "Value should not be valid");
                                 }
                             }
 
-                            if (exists $eg->{res}) {
-                                Test::More::is_deeply($res, $eg->{res}, 'result matches') or do {
+                            if (exists $eg->{validated_value} || exists $eg->{res}) {
+                                my $validated_value =
+                                    exists $eg->{validated_value} ? $eg->{validated_value} : $eg->{res};
+                                Test::More::is_deeply($res, $validated_value, 'Validated value matches') or do {
                                     $Test->diag($Test->explain($res));
                                     $ok = 0;
                                 };
@@ -258,7 +260,7 @@ Test::Sah::Schema - Test Sah::Schema::* modules in distribution
 
 =head1 VERSION
 
-This document describes version 0.004 of Test::Sah::Schema (from Perl distribution Test-Sah-Schema), released on 2020-03-04.
+This document describes version 0.005 of Test::Sah::Schema (from Perl distribution Test-Sah-Schema), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
